tonalitytools.OmissionIndicator
===============================

.. abjad-lineage:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator

.. autoclass:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__repr__
   :noindex:
